package org.apache.bcel.classfile;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.classfile.ConstantDouble;
import org.apache.bcel.classfile.ConstantFloat;
import org.apache.bcel.classfile.ConstantInteger;
import org.apache.bcel.classfile.ConstantLong;
import org.apache.bcel.classfile.ConstantPool;
import org.apache.bcel.classfile.ElementValue;

public class SimpleElementValue extends ElementValue {
  private int index;
  
  public SimpleElementValue(int type, int index, ConstantPool cpool) {
    super(type, cpool);
    this.index = index;
  }
  
  public void dump(DataOutputStream dos) throws IOException {
    int type = getType();
    dos.writeByte(type);
    switch (type) {
      case 66:
      case 67:
      case 68:
      case 70:
      case 73:
      case 74:
      case 83:
      case 90:
      case 115:
        dos.writeShort(getIndex());
        return;
    } 
    throw new IllegalStateException("SimpleElementValue doesnt know how to write out type " + type);
  }
  
  public int getIndex() {
    return this.index;
  }
  
  public boolean getValueBoolean() {
    if (getType() != 90)
      throw new IllegalStateException("Dont call getValueBoolean() on a non BOOLEAN ElementValue"); 
    ConstantInteger bo = (ConstantInteger)getConstantPool().getConstant(getIndex());
    return (bo.getBytes() != 0);
  }
  
  public byte getValueByte() {
    if (getType() != 66)
      throw new IllegalStateException("Dont call getValueByte() on a non BYTE ElementValue"); 
    return (byte)getConstantPool().getConstantInteger(getIndex()).getBytes();
  }
  
  public char getValueChar() {
    if (getType() != 67)
      throw new IllegalStateException("Dont call getValueChar() on a non CHAR ElementValue"); 
    return (char)getConstantPool().getConstantInteger(getIndex()).getBytes();
  }
  
  public double getValueDouble() {
    if (getType() != 68)
      throw new IllegalStateException("Dont call getValueDouble() on a non DOUBLE ElementValue"); 
    ConstantDouble d = (ConstantDouble)getConstantPool().getConstant(getIndex());
    return d.getBytes();
  }
  
  public float getValueFloat() {
    if (getType() != 70)
      throw new IllegalStateException("Dont call getValueFloat() on a non FLOAT ElementValue"); 
    ConstantFloat f = (ConstantFloat)getConstantPool().getConstant(getIndex());
    return f.getBytes();
  }
  
  public int getValueInt() {
    if (getType() != 73)
      throw new IllegalStateException("Dont call getValueString() on a non STRING ElementValue"); 
    return getConstantPool().getConstantInteger(getIndex()).getBytes();
  }
  
  public long getValueLong() {
    if (getType() != 74)
      throw new IllegalStateException("Dont call getValueLong() on a non LONG ElementValue"); 
    ConstantLong j = (ConstantLong)getConstantPool().getConstant(getIndex());
    return j.getBytes();
  }
  
  public short getValueShort() {
    if (getType() != 83)
      throw new IllegalStateException("Dont call getValueShort() on a non SHORT ElementValue"); 
    ConstantInteger s = (ConstantInteger)getConstantPool().getConstant(getIndex());
    return (short)s.getBytes();
  }
  
  public String getValueString() {
    if (getType() != 115)
      throw new IllegalStateException("Dont call getValueString() on a non STRING ElementValue"); 
    return getConstantPool().getConstantUtf8(getIndex()).getBytes();
  }
  
  public void setIndex(int index) {
    this.index = index;
  }
  
  public String stringifyValue() {
    ConstantLong j;
    ConstantDouble d;
    ConstantFloat f;
    ConstantInteger s, b, ch, bo;
    ConstantPool cpool = getConstantPool();
    int type = getType();
    switch (type) {
      case 73:
        return Integer.toString(cpool.getConstantInteger(getIndex()).getBytes());
      case 74:
        j = (ConstantLong)cpool.getConstant(getIndex(), (byte)5, ConstantLong.class);
        return Long.toString(j.getBytes());
      case 68:
        d = (ConstantDouble)cpool.getConstant(getIndex(), (byte)6, ConstantDouble.class);
        return Double.toString(d.getBytes());
      case 70:
        f = (ConstantFloat)cpool.getConstant(getIndex(), (byte)4, ConstantFloat.class);
        return Float.toString(f.getBytes());
      case 83:
        s = cpool.getConstantInteger(getIndex());
        return Integer.toString(s.getBytes());
      case 66:
        b = cpool.getConstantInteger(getIndex());
        return Integer.toString(b.getBytes());
      case 67:
        ch = cpool.getConstantInteger(getIndex());
        return String.valueOf((char)ch.getBytes());
      case 90:
        bo = cpool.getConstantInteger(getIndex());
        if (bo.getBytes() == 0)
          return "false"; 
        return "true";
      case 115:
        return cpool.getConstantUtf8(getIndex()).getBytes();
    } 
    throw new IllegalStateException("SimpleElementValue class does not know how to stringify type " + type);
  }
  
  public String toString() {
    return stringifyValue();
  }
}
